@@ -2,7 +2,7 @@ package Hyper::Control::Base::BTree;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('0.01');
+use version; our $VERSION = qv('0.02');
 
 use base qw(Hyper::Control::Base);
 use Class::Std::Storable;
@@ -24,6 +24,8 @@ sub STORABLE_thaw_post {
     # weaken up-reference in tree after thawing
     Scalar::Util::weaken($parent_of{ ident $_[0] })
         if defined $parent_of{ ident $_[0] };
+
+    $_[0]->SUPER::STORABLE_thaw_post();
 }
 
 sub add_child {
@@ -46,12 +48,11 @@ sub has_childs {
 sub has_next_sibling {
     my $self   = shift;
     my $parent = $self->get_parent() or return;
-    return $self->get_position() != $#{@{$parent->get_childs()}};
+    return $self->get_position() != ( @{$parent->get_childs()} - 1 );
 }
 
 sub has_previous_sibling {
-    my $self = shift;
-    return ! shift->get_position();
+    return $_[0]->get_position(); # 0 if no previos sibling exists
 }
 
 sub is_root {
@@ -92,7 +93,7 @@ Hyper::Control::Base::BTree - Tree Base Control
 
 =head1 VERSION
 
-This document describes Hyper::Control::Base::BTree 0.01
+This document describes Hyper::Control::Base::BTree 0.02
 
 =head1 SYNOPSIS
 
@@ -127,6 +128,26 @@ Base Control for HTML Trees.
 
 Add a child to a tree object. Childs are Tree Objects too.
 
+=head2 set_parent
+
+    $node->set_parent($root);
+
+Set parent object for node.
+
+=head2 get_path
+
+    # Sample Tree:
+    # ROOT
+    # '- child1
+    #   '- child2
+    #   '- child3
+
+    $child1->get_path(); # [ 0 ]
+    $child2->get_path(); # [ 0, 0 ]
+    $child3->get_path(); # [ 0, 1 ]
+
+Get path from child to root node.
+
 =head2 has_childs
 
     my $has_childs = $object->has_childs();
@@ -201,23 +222,23 @@ Class::Std::Storable
 
 =item Last changed by
 
-$Author: kutterma $
+$Author: ac0v $
 
 =item Id
 
-$Id: BTree.pm 497 2008-06-09 13:43:40Z kutterma $
+$Id: BTree.pm 528 2009-01-11 05:43:02Z ac0v $
 
 =item Revision
 
-$Revision: 497 $
+$Revision: 528 $
 
 =item Date
 
-$Date: 2008-06-09 15:43:40 +0200 (Mo, 09 Jun 2008) $
+$Date: 2009-01-11 06:43:02 +0100 (So, 11 Jan 2009) $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/branches/0.04/lib/Hyper/Control/Base/BTree.pm $
+$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/tags/0.05/lib/Hyper/Control/Base/BTree.pm $
 
 =back
 
