@@ -7,19 +7,11 @@ use Test::Exception;
 
 use base qw(Test::Class::Hyper);
 
-sub validator :Test(5) {
+sub validator :Test(4) {
     use_ok('Hyper::Validator');
     ok(my $obj = Hyper::Validator->new(), 'Object creation');
-
-    throws_ok(
-        sub { $obj->is_valid(); },
-        qr{Can't\slocate\sobject\smethod\s"VALIDATE"\svia\spackage\s"Hyper::Validator"},
-        'is_valid() calls VALIDATE method',
-    );
-
     ok($obj->get_is_valid(), 'is_valid default value is true');
 
-
     throws_ok(
         sub { $obj->get_html() },
         qr{Hyper/Validator\.htc}ms,
